package com.lzmispt.data.resource.service.file.impl;

package .tmp;

import com.alibaba.csp.sentinel.util.StringUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.google.common.base.Joiner;
import com.lzmispt.core.entity.dto.querymodel.QueryModelDTO;
import com.lzmispt.core.entity.dto.querymodel.SortModelDTO;
import com.lzmispt.core.service.query.IQuery;
import com.lzmispt.data.center.entity.dto.databasestruct.ColumnParamDTO;
import com.lzmispt.data.center.entity.dto.databasestruct.DataSourceDTO;
import com.lzmispt.data.center.entity.dto.databasestruct.TableParamDTO;
import com.lzmispt.data.center.entity.dto.log.CommonLogDTO;
import com.lzmispt.data.center.entity.dto.querymodel.DCQueryModelDTO;
import com.lzmispt.data.center.entity.dto.resource.file.DeleteFileTableDTO;
import com.lzmispt.data.center.entity.dto.resource.metadata.DeleteFileTableMsg;
import com.lzmispt.data.center.entity.dto.resource.metadata.FileTableUsedInfoDTO;
import com.lzmispt.data.center.entity.enums.FileSysFieldEnum;
import com.lzmispt.data.center.entity.enums.StatusCodeEnum;
import com.lzmispt.data.center.entity.vo.dcinterface.InterfaceEntityRelationVO;
import com.lzmispt.data.center.entity.vo.resource.datasource.DataSourceVO;
import com.lzmispt.data.center.entity.vo.resource.file.FileInfoTableVO;
import com.lzmispt.data.center.entity.vo.resource.file.FileTableUsedInterfaceVO;
import com.lzmispt.data.center.entity.vo.resource.metadata.FileTableUsageVO;
import com.lzmispt.data.center.entity.vo.standard.metadata.MetadataTypeVO;
import com.lzmispt.data.resource.client.DataInterfaceClient;
import com.lzmispt.data.resource.client.DataStandardClient;
import com.lzmispt.data.resource.dao.developconfig.impl.DevelopConfigDaoImpl;
import com.lzmispt.data.resource.dao.file.IFileInfoFieldDao;
import com.lzmispt.data.resource.dao.file.IFileInfoTableDao;
import com.lzmispt.data.resource.dao.metadata.IMetadataDao;
import com.lzmispt.data.resource.entity.dto.file.AddFileInfoTableDTO;
import com.lzmispt.data.resource.entity.dto.file.CheckFileInfoDTO;
import com.lzmispt.data.resource.entity.dto.file.QueryFileInfoTableDTO;
import com.lzmispt.data.resource.entity.dto.file.UpdateFileInfoTableDTO;
import com.lzmispt.data.resource.entity.po.developconfig.DevelopConfigPO;
import com.lzmispt.data.resource.entity.po.file.FileInfoFieldPO;
import com.lzmispt.data.resource.entity.po.file.FileInfoTablePO;
import com.lzmispt.data.resource.entity.po.metadata.MetadataDirectoryPO;
import com.lzmispt.data.resource.entity.po.metadata.MetadataEntityPO;
import com.lzmispt.data.resource.service.file.IFileInfoTable;
import com.lzmispt.data.resource.service.history.HistoryTableManager;
import com.lzmispt.dcbase.ServiceUtil;
import com.lzmispt.dcbase.database.IManage;
import com.lzmispt.dcbase.databasestruct.DataStructProvider;
import com.lzmispt.dcbase.dcconst.DCConst;
import com.lzmispt.dcbase.sysfield.SysFieldHelper;
import com.lzmispt.dcbase.util.HeaderInterceptor;
import com.lzmispt.framework.entity.entity.ResultEntity;
import com.lzmispt.framework.exception.ExceptionUtil;
import com.lzmispt.framework.fconst.FrameConst;
import com.lzmispt.framework.utils.DBKeywordUtil;
import com.lzmispt.framework.utils.RabbitMQUtil;
import com.lzmispt.framework.utils.WorkerId;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.cloud.context.config.annotation.RefreshScope;
import org.springframework.util.CollectionUtils;
import org.springframework.util.StringUtils;

@RefreshScope
public abstract class FileInfoTableManager implements IFileInfoTable, IManage {
  private static final Integer CN_NAME_MAX_LENGTH = Integer.valueOf(100);
  
  private static final Integer CODE_MAX_LENGTH = Integer.valueOf(100);
  
  private static final Integer DESCRIPTION_MAX_LENGTH = Integer.valueOf(500);
  
  private static final String CN_NAME_OVERLONG_MSG = "文件表中文名长度超过" + CN_NAME_MAX_LENGTH;
  
  private static final String CODE_OVERLONG_MSG = "文件表编码长度超过" + CODE_MAX_LENGTH;
  
  private static final String DESCRIPTION_OVERLONG_MSG = "文件表备注长度超过" + DESCRIPTION_MAX_LENGTH;
  
  private static final Integer FIELD_LENGTH_10 = Integer.valueOf(10);
  
  private static final Integer FIELD_LENGTH_20 = Integer.valueOf(20);
  
  private static final Integer FIELD_LENGTH_36 = Integer.valueOf(36);
  
  private static final Integer FIELD_LENGTH_50 = Integer.valueOf(50);
  
  private static final Integer FIELD_LENGTH_500 = Integer.valueOf(500);
  
  private static final Integer FIELD_LENGTH_2000 = Integer.valueOf(2000);
  
  private static final Integer FIELD_LENGTH_4000 = Integer.valueOf(4000);
  
  private static final Integer COLUMN_LENGTH_10 = Integer.valueOf(10);
  
  private static final Integer COLUMN_LENGTH_20 = Integer.valueOf(20);
  
  private static final Integer COLUMN_LENGTH_36 = Integer.valueOf(36);
  
  private static final Integer COLUMN_LENGTH_50 = Integer.valueOf(50);
  
  private static final Integer COLUMN_LENGTH_500 = Integer.valueOf(500);
  
  private static final Integer COLUMN_LENGTH_2000 = Integer.valueOf(2000);
  
  private static final Integer COLUMN_LENGTH_4000 = Integer.valueOf(4000);
  
  @Autowired
  DataStandardClient dataStandardClient;
  
  @Autowired
  DataInterfaceClient dataInterfaceClient;
  
  @Autowired
  private HistoryTableManager historyTableManager;
  
  @Autowired
  private DevelopConfigDaoImpl developConfigDao;
  
  @Value("${data-center.run-mode}")
  private String runMode;
  
  @Value("${data-center.data-authority.collection}")
  private String collectionAuthority;
  
  @Value("${data-center.data-authority.manage}")
  private String manageAuthority;
  
  @Value("${data-center.data-mode:mysql}")
  private String dbType;
  
  @Value("${data-center.primary-key-mode}")
  private String primaryKeyMode;
  
  @Autowired
  private IQuery query;
  
  public ResultEntity<Map> selectFileInfoTableList(QueryFileInfoTableDTO queryDataInterfaceDTO) {
    String authority = getDefaultCode().equals("Collection") ? this.collectionAuthority : this.manageAuthority;
    IFileInfoTableDao fileInfoTableDao = (IFileInfoTableDao)ServiceUtil.getFileInfoTableDao(getDefaultCode(), IFileInfoTableDao.class);
    Map<String, Object> param = new HashMap<>();
    Map<String, Object> resultMap = new HashMap<>();
    if ("org".equals(authority)) {
      param.put("organizationId", queryDataInterfaceDTO.getOrganizationId());
    } else if ("userorg".equals(authority)) {
      param.put("userId", queryDataInterfaceDTO.getUserId());
      param.put("organizationId", queryDataInterfaceDTO.getOrganizationId());
    } 
    DCQueryModelDTO queryModel = queryDataInterfaceDTO.getQuery();
    String whereSql = null;
    if (queryModel != null) {
      List<SortModelDTO> sortModels = queryModel.getSortModels();
      if (sortModels != null)
        for (SortModelDTO sortModel : sortModels) {
          if ("name".equals(sortModel.getFieldName())) {
            param.put("needJoin", Boolean.valueOf(true));
            break;
          } 
        }  
      boolean isEscapeStr = false;
      if (this.dbType.equalsIgnoreCase("sqlserver"))
        isEscapeStr = true; 
      whereSql = (String)this.query.getWhereSqlStr((QueryModelDTO)queryModel, this.dbType, true, isEscapeStr).getObj();
      if (!StringUtil.isEmpty(whereSql) && queryModel.getFilterModel() != null)
        whereSql = " and " + whereSql; 
      param.put("query", whereSql);
    } 
    List<FileInfoTablePO> selectList = fileInfoTableDao.selectFileInfoTableList(param);
    List<FileInfoTableVO> list = new ArrayList<>();
    FileInfoTableVO fileInfoTableVO = null;
    if (!CollectionUtils.isEmpty(selectList))
      for (FileInfoTablePO item : selectList) {
        fileInfoTableVO = new FileInfoTableVO();
        BeanUtils.copyProperties(item, fileInfoTableVO);
        list.add(fileInfoTableVO);
      }  
    resultMap.put("list", list);
    if (queryDataInterfaceDTO.getQuery().getPageSize() != null) {
      queryDataInterfaceDTO.getQuery().setPageSize(null);
      queryDataInterfaceDTO.getQuery().setPageIndex(null);
      queryDataInterfaceDTO.getQuery().setSortModels(null);
      boolean isEscapeStr = false;
      if (this.dbType.equalsIgnoreCase("sqlserver"))
        isEscapeStr = true; 
      whereSql = (String)this.query.getWhereSqlStr((QueryModelDTO)queryModel, this.dbType, true, isEscapeStr).getObj();
      if (!StringUtil.isEmpty(whereSql) && queryModel.getFilterModel() != null)
        whereSql = " and " + whereSql; 
      param.put("query", whereSql);
      int total = fileInfoTableDao.selectFileInfoTableListCount(param);
      resultMap.put("total", Integer.valueOf(total));
    } 
    return ResultEntity.successMessage(resultMap);
  }
  
  public ResultEntity<Integer> getNewTableOrder(Integer dataCategory) {
    IFileInfoTableDao fileInfoTableDao = (IFileInfoTableDao)ServiceUtil.getFileInfoTableDao(getDefaultCode(), IFileInfoTableDao.class);
    Integer maxOrder = fileInfoTableDao.getFileTableOrderMax(dataCategory);
    return ResultEntity.successMessage(Integer.valueOf((maxOrder == null) ? 1 : ((maxOrder.intValue() == Integer.MAX_VALUE) ? Integer.MAX_VALUE : (maxOrder.intValue() + 1))));
  }
  
  public ResultEntity<Boolean> insertFileInfoTable(AddFileInfoTableDTO addFileInfoTableDTO, String tokenId) {
    if (!StringUtils.isEmpty(addFileInfoTableDTO.getFileTableCode()) && addFileInfoTableDTO.getFileTableCode().length() > CODE_MAX_LENGTH.intValue())
      return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_FILE_TABLE_CODE_EXCEEDS_HUNDRED.getCode()), CODE_OVERLONG_MSG); 
    if (!StringUtils.isEmpty(addFileInfoTableDTO.getDescription()) && addFileInfoTableDTO.getDescription().length() > DESCRIPTION_MAX_LENGTH.intValue())
      return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_FILE_TABLE_REMARK_EXCEEDS_FIVE_HUNDRED.getCode()), DESCRIPTION_OVERLONG_MSG); 
    if (StringUtils.isEmpty(addFileInfoTableDTO.getFileTableCode()))
      return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_FILE_TABLE_CODE_IS_NULL.getCode()), StatusCodeEnum.DATA_RESOURCE_FILE_TABLE_CODE_IS_NULL.getMessage()); 
    IFileInfoTableDao fileInfoTableDao = (IFileInfoTableDao)ServiceUtil.getFileInfoTableDao(getDefaultCode(), IFileInfoTableDao.class);
    List<FileInfoTablePO> fileTableList = fileInfoTableDao.getFileTableByCode(addFileInfoTableDTO.getFileTableCode(), null);
    if (fileTableList.size() > 0)
      return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_FILE_TABLE_CODE_EXIST.getCode()), StatusCodeEnum.DATA_RESOURCE_FILE_TABLE_CODE_EXIST.getMessage()); 
    if (addFileInfoTableDTO.getFileTableOrder() == null) {
      Integer maxOrder = fileInfoTableDao.getFileTableOrderMax(addFileInfoTableDTO.getDataCategory());
      addFileInfoTableDTO.setFileTableOrder(Integer.valueOf((maxOrder == null) ? 1 : ((maxOrder.intValue() == Integer.MAX_VALUE) ? Integer.MAX_VALUE : (maxOrder.intValue() + 1))));
    } 
    FileInfoTablePO fileInfoTablePO = new FileInfoTablePO();
    Long fileTableId = (Long)WorkerId.getNextId(Long.class);
    BeanUtils.copyProperties(addFileInfoTableDTO, fileInfoTablePO);
    fileInfoTablePO.setDirectoryId(null);
    fileInfoTablePO.setFileTableId(fileTableId);
    DevelopConfigPO developConfig = this.developConfigDao.getDevelopConfig(getDefaultCode());
    if (developConfig != null) {
      JSONObject jsonObject = JSONObject.parseObject(developConfig.getConfigPlatJson());
      String fileRootPath = (jsonObject != null && !StringUtils.isEmpty(jsonObject.getString("fileRootPath"))) ? jsonObject.getString("fileRootPath") : "DataCenter";
      fileInfoTablePO.setFileRootPath(fileRootPath);
    } else {
      fileInfoTablePO.setFileRootPath("DataCenter");
    } 
    fileInfoTablePO.setCreateTime(new Date());
    fileInfoTablePO.setUpdateTime(new Date());
    fileInfoTablePO.setIsDelete(DCConst.FALSE);
    if (!addFileInfoField(fileInfoTablePO.getFileTableId(), addFileInfoTableDTO.getUserId(), addFileInfoTableDTO.getOrganizationId()))
      return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_CREATE_FILE_INFO_TABLE_FAILED.getCode()), StatusCodeEnum.DATA_RESOURCE_CREATE_FILE_INFO_TABLE_FAILED.getMessage()); 
    if (fileInfoTableDao.insertFileInfoTable(fileInfoTablePO) > 0) {
      relateFileTableToMetadataDirectory(addFileInfoTableDTO.getDirectoryId(), fileInfoTablePO.getFileTableId());
      logSystemInfo("新增文件信息表 文件表编码:【" + addFileInfoTableDTO.getFileTableCode() + "】,文件表英文名:【" + addFileInfoTableDTO.getFileTableName() + "】", getDefaultCode(), addFileInfoTableDTO.getTokenId());
      return ResultEntity.successMessage(Boolean.valueOf(true));
    } 
    return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_ADD_FILE_TABLE_FAILED.getCode()), StatusCodeEnum.DATA_RESOURCE_ADD_FILE_TABLE_FAILED.getMessage());
  }
  
  private boolean relateFileTableToMetadataDirectory(Long directoryId, Long fileTableId) {
    if (directoryId == null || fileTableId == null)
      return false; 
    IMetadataDao metadataDao = (IMetadataDao)ServiceUtil.getMetadataDao(getDefaultCode(), IMetadataDao.class);
    MetadataDirectoryPO metadataDirectoryPO = metadataDao.selectDirectoryByDirectoryId(directoryId);
    metadataDirectoryPO.setFileTableId(fileTableId);
    metadataDirectoryPO.setUpdateTime(new Date());
    return (metadataDao.updateMetadataDirectory(metadataDirectoryPO).intValue() > 0);
  }
  
  public boolean checkHaveFileTableNameInDB(DataStructProvider dataStructProvider, String fileTableName) {
    return dataStructProvider.isExistsTable(fileTableName).booleanValue();
  }
  
  public ResultEntity<Boolean> checkFileTableNameIsExist(CheckFileInfoDTO checkFileInfoDTO, String tokenId) {
    IFileInfoTableDao fileInfoTableDao = (IFileInfoTableDao)ServiceUtil.getFileInfoTableDao(getDefaultCode(), IFileInfoTableDao.class);
    DataSourceVO dataSourceVO = null;
    if (checkFileInfoDTO.getDataSourceId() != null)
      dataSourceVO = (DataSourceVO)this.dataStandardClient.getDataSourceInfoDoNotDecryptById(checkFileInfoDTO.getDataSourceId(), getDefaultCode(), tokenId).getObj(); 
    if (dataSourceVO == null) {
      logErrorInfo(null, "校验文件表英文名出错, 根据Id获取配置的数据库实例失败! 数据源id:" + checkFileInfoDTO.getDataSourceId(), getDefaultCode(), tokenId);
      return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_GET_CONFIG_DB_FAILED.getCode()), StatusCodeEnum.DATA_RESOURCE_GET_CONFIG_DB_FAILED
          .getMessage());
    } 
    if (DBKeywordUtil.isDBKeyword(checkFileInfoDTO.getTableName(), dataSourceVO.getType()))
      return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_DATA_TABLE_NAME_IS_KEYWORD.getCode()), 
          String.format(StatusCodeEnum.DATA_RESOURCE_DATA_TABLE_NAME_IS_KEYWORD.getMessage(), new Object[] { checkFileInfoDTO.getTableName() }), Boolean.valueOf(true)); 
    List<FileInfoTablePO> list = fileInfoTableDao.getTableByNameAndDataSourceId(checkFileInfoDTO.getDataSourceId(), checkFileInfoDTO.getTableName(), checkFileInfoDTO.getFileTableId());
    if (list != null && list.size() > 0)
      return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_DATA_TABLE_NAME_EXISTS.getCode()), 
          String.format(StatusCodeEnum.DATA_RESOURCE_DATA_TABLE_NAME_EXISTS.getMessage(), new Object[] { checkFileInfoDTO.getTableName() }), Boolean.valueOf(true)); 
    DataSourceDTO dataSourceDTO = new DataSourceDTO();
    BeanUtils.copyProperties(dataSourceVO, dataSourceDTO);
    ResultEntity<DataStructProvider> getDataBaseProviderRet = DataStructProvider.getDataBaseProvider(dataSourceDTO);
    if (!getDataBaseProviderRet.getCode().equals(Integer.valueOf(0)))
      return ResultEntity.errorMessage(getDataBaseProviderRet.getCode(), getDataBaseProviderRet.getMsg()); 
    DataStructProvider dataStructProvider = (DataStructProvider)getDataBaseProviderRet.getObj();
    if (checkHaveFileTableNameInDB(dataStructProvider, checkFileInfoDTO.getTableName()))
      return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_DATA_TABLE_NAME_EXISTS.getCode()), 
          String.format(StatusCodeEnum.DATA_RESOURCE_DATA_TABLE_NAME_EXISTS.getMessage(), new Object[] { checkFileInfoDTO.getTableName() }), Boolean.valueOf(true)); 
    return ResultEntity.successMessage(Boolean.valueOf(false));
  }
  
  public boolean addFileInfoField(Long fileTableId, Long userId, Long organizationId) {
    Object object = new Object(this, fileTableId, userId, organizationId);
    if (DCConst.PrimaryKeyMode.GUID.equals(this.primaryKeyMode)) {
      object.add(new FileInfoFieldPO((Long)WorkerId.getNextId(Long.class), fileTableId, SysFieldHelper.getFileSysFieldName(FileSysFieldEnum.DBID), "数据表主键id", "String", FIELD_LENGTH_36, Integer.valueOf(0), Integer.valueOf(1), Integer.valueOf(0), Integer.valueOf(object.size() + 1), userId, organizationId));
    } else {
      object.add(new FileInfoFieldPO((Long)WorkerId.getNextId(Long.class), fileTableId, SysFieldHelper.getFileSysFieldName(FileSysFieldEnum.DBID), "数据表主键id", "Long", FIELD_LENGTH_20, Integer.valueOf(0), Integer.valueOf(1), Integer.valueOf(0), Integer.valueOf(object.size() + 1), userId, organizationId));
    } 
    for (FileInfoFieldPO addFileInfoField : object) {
      addFileInfoField.setShowInEdit(DCConst.TRUE);
      addFileInfoField.setShowInBrowse(DCConst.TRUE);
    } 
    int count = ((IFileInfoFieldDao)ServiceUtil.getFileInfoFieldDao(getDefaultCode(), IFileInfoFieldDao.class)).insertFileInfoFieldList((List)object);
    return (count > 0);
  }
  
  public ResultEntity<Boolean> updateFileInfoTable(UpdateFileInfoTableDTO updateFileInfoTableDTO, String tokenId) {
    if (!StringUtils.isEmpty(updateFileInfoTableDTO.getFileTableCnName()) && updateFileInfoTableDTO.getFileTableCnName().length() > CN_NAME_MAX_LENGTH.intValue())
      return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_FILE_TABLE_CN_NAME_EXCEEDS_HUNDRED.getCode()), CN_NAME_OVERLONG_MSG); 
    if (!StringUtils.isEmpty(updateFileInfoTableDTO.getDescription()) && updateFileInfoTableDTO.getDescription().length() > DESCRIPTION_MAX_LENGTH.intValue())
      return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_FILE_TABLE_REMARK_EXCEEDS_FIVE_HUNDRED.getCode()), DESCRIPTION_OVERLONG_MSG); 
    if (StringUtils.isEmpty(updateFileInfoTableDTO.getFileTableCode()))
      return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_FILE_TABLE_CODE_IS_NULL.getCode()), StatusCodeEnum.DATA_RESOURCE_FILE_TABLE_CODE_IS_NULL.getMessage()); 
    FileInfoTablePO updateFileInfoTablePO = new FileInfoTablePO();
    FileInfoTablePO fileInfoTablePO = ((IFileInfoTableDao)ServiceUtil.getFileInfoTableDao(getDefaultCode(), IFileInfoTableDao.class)).selectFileInfoTable(updateFileInfoTableDTO.getFileTableId());
    if (checkFileTableCodeExist(fileInfoTablePO, updateFileInfoTableDTO))
      return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_FILE_TABLE_CODE_EXIST.getCode()), StatusCodeEnum.DATA_RESOURCE_FILE_TABLE_CODE_EXIST.getMessage()); 
    if (fileInfoTablePO == null || DCConst.TRUE.equals(fileInfoTablePO.getIsDelete()))
      return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_FILE_INFO_TABLE_NO_EXISTS.getCode()), StatusCodeEnum.DATA_RESOURCE_FILE_INFO_TABLE_NO_EXISTS.getMessage()); 
    Long dataSourceId = (updateFileInfoTableDTO.getDataSourceId() != null) ? updateFileInfoTableDTO.getDataSourceId() : fileInfoTablePO.getDataSourceId();
    if (dataSourceId == null)
      return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_DATA_SOURCE_IS_NULL.getCode()), StatusCodeEnum.DATA_RESOURCE_DATA_SOURCE_IS_NULL.getMessage()); 
    boolean fileTableNameChange = (!StringUtils.isEmpty(updateFileInfoTableDTO.getFileTableName()) && !updateFileInfoTableDTO.getFileTableName().equals(fileInfoTablePO.getFileTableName()));
    boolean dataSourceIdChange = (updateFileInfoTableDTO.getDataSourceId() != null && !updateFileInfoTableDTO.getDataSourceId().equals(fileInfoTablePO.getDataSourceId()));
    if (fileTableNameChange || dataSourceIdChange) {
      ResultEntity<Boolean> resultEntity = fileTableIsSync(fileInfoTablePO, tokenId);
      if (resultEntity.getCode().intValue() != 0)
        return resultEntity; 
      List<FileInfoTablePO> list = ((IFileInfoTableDao)ServiceUtil.getFileInfoTableDao(getDefaultCode(), IFileInfoTableDao.class)).getTableByNameAndDataSourceId(fileInfoTablePO.getDataSourceId(), updateFileInfoTableDTO.getFileTableName(), updateFileInfoTableDTO.getFileTableId());
      if (list.size() > 0)
        return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_NEW_FILE_TABLE_EN_NAME_EXISTS.getCode()), StatusCodeEnum.DATA_RESOURCE_NEW_FILE_TABLE_EN_NAME_EXISTS.getMessage()); 
      DataSourceVO dataSourceVO = null;
      if (dataSourceId != null)
        dataSourceVO = (DataSourceVO)this.dataStandardClient.getDataSourceInfoDoNotDecryptById(dataSourceId, getDefaultCode(), tokenId).getObj(); 
      if (dataSourceVO == null)
        return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_GET_CONFIG_DB_FAILED.getCode()), StatusCodeEnum.DATA_RESOURCE_GET_CONFIG_DB_FAILED.getMessage()); 
      if (DBKeywordUtil.isDBKeyword(updateFileInfoTableDTO.getFileTableName(), dataSourceVO.getType()))
        return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_DATA_TABLE_EN_NAME_IS_KEYWORD.getCode()), StatusCodeEnum.DATA_RESOURCE_DATA_TABLE_EN_NAME_IS_KEYWORD
            .getMessage()); 
      DataSourceDTO dataSourceDTO = new DataSourceDTO();
      BeanUtils.copyProperties(dataSourceVO, dataSourceDTO);
      ResultEntity<DataStructProvider> getDataBaseProviderRet = DataStructProvider.getDataBaseProvider(dataSourceDTO);
      if (!getDataBaseProviderRet.getCode().equals(Integer.valueOf(0)))
        return ResultEntity.errorMessage(getDataBaseProviderRet.getCode(), getDataBaseProviderRet.getMsg()); 
      DataStructProvider dataStructProvider = (DataStructProvider)getDataBaseProviderRet.getObj();
      if (checkHaveFileTableNameInDB(dataStructProvider, updateFileInfoTableDTO.getFileTableName()))
        return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_DATA_TABLE_EXISTS_IN_DATA_SOURCE.getCode()), StatusCodeEnum.DATA_RESOURCE_DATA_TABLE_EXISTS_IN_DATA_SOURCE.getMessage()); 
      if (fileTableNameChange)
        updateFileInfoTablePO.setFileTableName(updateFileInfoTableDTO.getFileTableName()); 
      if (dataSourceIdChange)
        updateFileInfoTablePO.setDataSourceId(updateFileInfoTableDTO.getDataSourceId()); 
    } 
    updateFileInfoTablePO.setFileTableId(updateFileInfoTableDTO.getFileTableId());
    updateFileInfoTablePO.setFileTableCode(updateFileInfoTableDTO.getFileTableCode());
    updateFileInfoTablePO.setFileTableOrder(updateFileInfoTableDTO.getFileTableOrder());
    updateFileInfoTablePO.setFileTableCnName(updateFileInfoTableDTO.getFileTableCnName());
    updateFileInfoTablePO.setDescription(updateFileInfoTableDTO.getDescription());
    updateFileInfoTablePO.setUpdateTime(new Date());
    if (((IFileInfoTableDao)ServiceUtil.getFileInfoTableDao(getDefaultCode(), IFileInfoTableDao.class)).updateFileInfoTableSelective(updateFileInfoTablePO) > 0) {
      StringBuilder logInfo = new StringBuilder("修改文件信息表 ");
      if (!StringUtils.isEmpty(updateFileInfoTableDTO.getFileTableName()) && !updateFileInfoTableDTO.getFileTableName().equals(fileInfoTablePO.getFileTableName()))
        logInfo.append("文件信息表英文名:【").append(fileInfoTablePO.getFileTableName()).append("】修改为").append("【").append(updateFileInfoTableDTO.getFileTableName()).append("】;"); 
      if (!StringUtils.isEmpty(updateFileInfoTableDTO.getFileTableCnName()) && !updateFileInfoTableDTO.getFileTableCnName().equals(fileInfoTablePO.getFileTableCnName()))
        logInfo.append("文件信息表中文名:【").append(fileInfoTablePO.getFileTableCnName()).append("】修改为").append("【").append(updateFileInfoTableDTO.getFileTableCnName()).append("】;"); 
      logSystemInfo(logInfo.substring(0, logInfo.length() - 1), getDefaultCode(), tokenId);
      return ResultEntity.successMessage(Boolean.valueOf(true));
    } 
    return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_UPDATE_FILE_TABLE_FAILED.getCode()), StatusCodeEnum.DATA_RESOURCE_UPDATE_FILE_TABLE_FAILED.getMessage());
  }
  
  private boolean checkFileTableCodeExist(FileInfoTablePO fileInfoTablePO, UpdateFileInfoTableDTO updateFileInfoTableDTO) {
    if (updateFileInfoTableDTO.getFileTableCode().equals(fileInfoTablePO.getFileTableCode()))
      return false; 
    List<FileInfoTablePO> fileTableList = ((IFileInfoTableDao)ServiceUtil.getFileInfoTableDao(getDefaultCode(), IFileInfoTableDao.class)).getFileTableByCode(updateFileInfoTableDTO.getFileTableCode(), fileInfoTablePO.getFileTableId());
    if (fileTableList.size() > 0)
      return true; 
    return false;
  }
  
  private ResultEntity<Boolean> fileTableIsSync(FileInfoTablePO fileInfoTablePO, String tokenId) {
    if (fileInfoTablePO.getFileTableName() == null || fileInfoTablePO.getDataSourceId() == null)
      return ResultEntity.successMessage(Boolean.valueOf(false)); 
    try {
      DataSourceVO dataSourceVO = null;
      if (fileInfoTablePO.getDataSourceId() != null)
        dataSourceVO = (DataSourceVO)this.dataStandardClient.getDataSourceInfoDoNotDecryptById(fileInfoTablePO.getDataSourceId(), getDefaultCode(), tokenId).getObj(); 
      if (dataSourceVO == null)
        return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_GET_CONFIG_DB_FAILED.getCode()), StatusCodeEnum.DATA_RESOURCE_GET_CONFIG_DB_FAILED.getMessage()); 
      DataSourceDTO dataSourceDTO = new DataSourceDTO();
      BeanUtils.copyProperties(dataSourceVO, dataSourceDTO);
      ResultEntity<DataStructProvider> getDataBaseProviderRet = DataStructProvider.getDataBaseProvider(dataSourceDTO);
      if (!getDataBaseProviderRet.getCode().equals(Integer.valueOf(0)))
        return ResultEntity.errorMessage(getDataBaseProviderRet.getCode(), getDataBaseProviderRet.getMsg()); 
      DataStructProvider dataStructProvider = (DataStructProvider)getDataBaseProviderRet.getObj();
      Boolean existsTable = dataStructProvider.isExistsTable(fileInfoTablePO.getFileTableName());
      if (existsTable.booleanValue())
        return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_TABLE_HAS_SYNC_FAILED.getCode()), StatusCodeEnum.DATA_RESOURCE_TABLE_HAS_SYNC_FAILED.getMessage()); 
      return ResultEntity.successMessage(Boolean.valueOf(false));
    } catch (Exception e) {
      return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_CHECK_TABLE_SYNC_FAILED.getCode()), StatusCodeEnum.DATA_RESOURCE_CHECK_TABLE_SYNC_FAILED.getMessage());
    } 
  }
  
  public ResultEntity<Object> delFileInfoTable(DeleteFileTableDTO deleteFileTableDTO, String tokenId) {
    if (!"fileTableId".equalsIgnoreCase(deleteFileTableDTO.getDeleteField()) && CollectionUtils.isEmpty(deleteFileTableDTO.getSelectKeys()))
      return ResultEntity.errorMessage(Integer.valueOf(-1), "删除文件表参数不正确"); 
    return delFileInfoTable(deleteFileTableDTO.getDirectoryId(), deleteFileTableDTO.getSelectKeys().get(0), tokenId);
  }
  
  public ResultEntity<Object> delFileInfoTable(Long directoryId, Long fileTableId, String tokenId) {
    List<String> deletedTableCnNames = new ArrayList<>();
    Map<Long, DataStructProvider> providerMap = new HashMap<>();
    boolean success = delFileInfoTable(fileTableId, providerMap, deletedTableCnNames, tokenId);
    if (success) {
      StringBuilder logInfo = new StringBuilder();
      logInfo.append("删除文件信息表 文件信息表【").append(deletedTableCnNames.get(0)).append("】");
      logSystemInfo(logInfo.toString(), getDefaultCode(), tokenId);
      DeleteFileTableMsg msg = new DeleteFileTableMsg();
      msg.setDirectoryId(directoryId);
      msg.setFileTableId(fileTableId);
      msg.setTokenId(tokenId);
      msg.setPlatCode(getDefaultCode());
      RabbitMQUtil.publish("DC.Resource.deleteFileTable", msg);
      return ResultEntity.successMessage(Boolean.valueOf(true));
    } 
    return ResultEntity.errorMessage(Integer.valueOf(-1), "删除文件表失败");
  }
  
  public ResultEntity<Object> delFileInfoTableByEntityId(Long entityId, Long fileTableId, String tokenId) {
    List<String> deletedTableCnNames = new ArrayList<>();
    Map<Long, DataStructProvider> providerMap = new HashMap<>();
    boolean success = delFileInfoTable(fileTableId, providerMap, deletedTableCnNames, tokenId);
    if (success) {
      StringBuilder logInfo = new StringBuilder();
      logInfo.append("删除文件信息表 文件信息表【").append(deletedTableCnNames.get(0)).append("】");
      logSystemInfo(logInfo.toString(), getDefaultCode(), tokenId);
      DeleteFileTableMsg msg = new DeleteFileTableMsg();
      msg.setEntityId(entityId);
      msg.setFileTableId(fileTableId);
      msg.setTokenId(tokenId);
      msg.setPlatCode(getDefaultCode());
      RabbitMQUtil.publish("DC.Resource.deleteFileTable", msg);
      return ResultEntity.successMessage(Boolean.valueOf(true));
    } 
    return ResultEntity.errorMessage(Integer.valueOf(-1), "删除文件表失败");
  }
  
  private boolean delFileInfoTable(Long fileTableId, Map<Long, DataStructProvider> providerMap, List<String> deletedTableCnNames, String tokenId) {
    FileInfoTablePO fileInfoTablePO = ((IFileInfoTableDao)ServiceUtil.getFileInfoTableDao(getDefaultCode(), IFileInfoTableDao.class)).selectFileInfoTable(fileTableId);
    if (fileInfoTablePO == null || DCConst.TRUE.equals(fileInfoTablePO.getIsDelete()))
      return true; 
    if (fileInfoTablePO.getDataSourceId() != null) {
      DataStructProvider dataStructProvider;
      if (providerMap.containsKey(fileInfoTablePO.getDataSourceId())) {
        dataStructProvider = providerMap.get(fileInfoTablePO.getDataSourceId());
      } else {
        DataSourceVO dataSourceVO = (DataSourceVO)this.dataStandardClient.getDataSourceInfoDoNotDecryptById(fileInfoTablePO.getDataSourceId(), getDefaultCode(), tokenId).getObj();
        if (dataSourceVO == null) {
          logErrorInfo(null, "文件信息表【" + fileInfoTablePO.getFileTableName() + "】删除失败，根据Id获取配置的数据库实例失败，数据源id:【" + fileInfoTablePO.getDataSourceId() + "】", getDefaultCode(), tokenId);
          return false;
        } 
        DataSourceDTO dataSourceDTO = new DataSourceDTO();
        BeanUtils.copyProperties(dataSourceVO, dataSourceDTO);
        ResultEntity<DataStructProvider> getDataBaseProviderRet = DataStructProvider.getDataBaseProvider(dataSourceDTO);
        if (!getDataBaseProviderRet.getCode().equals(Integer.valueOf(0)))
          return false; 
        dataStructProvider = (DataStructProvider)getDataBaseProviderRet.getObj();
        providerMap.put(fileInfoTablePO.getDataSourceId(), dataStructProvider);
      } 
      boolean isExistsTable = dataStructProvider.isExistsTable(fileInfoTablePO.getFileTableName()).booleanValue();
      boolean haveTableData = (isExistsTable && dataStructProvider.getTableDataCount(fileInfoTablePO.getFileTableName()) > 0);
      if (isExistsTable && !haveTableData) {
        boolean isSuccess = delFileInfoDbTable(dataStructProvider, fileInfoTablePO.getFileTableName());
        if (!isSuccess) {
          logErrorInfo(null, "文件信息表【" + fileInfoTablePO.getFileTableName() + "】删除失败，删除物理表失败", getDefaultCode(), tokenId);
          return false;
        } 
        try {
          String historyTableName = getHistoryTableName(fileInfoTablePO.getFileTableName());
          delFileInfoDbTable(dataStructProvider, historyTableName);
        } catch (Exception e) {
          logErrorInfo(ExceptionUtil.getStackTraceMsg(e), "文件信息表【" + fileInfoTablePO.getFileTableName() + "】删除物理表成功, 但是删除历史表失败", getDefaultCode(), tokenId);
        } 
      } 
    } 
    List<MetadataDirectoryPO> applyEntityListOfFileTable = getApplyEntityListOfFileTable(fileInfoTablePO.getFileTableId());
    if (applyEntityListOfFileTable.size() > 0) {
      IMetadataDao metadataDao = (IMetadataDao)ServiceUtil.getMetadataDao(getDefaultCode(), IMetadataDao.class);
      for (MetadataDirectoryPO item : applyEntityListOfFileTable)
        metadataDao.delFileTableId(item.getDirectoryId()); 
    } 
    ((IFileInfoTableDao)ServiceUtil.getFileInfoTableDao(getDefaultCode(), IFileInfoTableDao.class)).deleteFileInfoTable(fileTableId);
    deletedTableCnNames.add(fileInfoTablePO.getFileTableCnName());
    return true;
  }
  
  private String getHistoryTableName(String fileTableName) {
    return fileTableName + "_history";
  }
  
  public ResultEntity<FileInfoTableVO> getFileTableByDirId(Long directoryId) {
    FileInfoTablePO fileInfoTable = ((IFileInfoTableDao)ServiceUtil.getFileInfoTableDao(getDefaultCode(), IFileInfoTableDao.class)).getFileTableByDirId(directoryId);
    if (fileInfoTable != null) {
      FileInfoTableVO fileInfoTableVO = new FileInfoTableVO();
      BeanUtils.copyProperties(fileInfoTable, fileInfoTableVO);
      return ResultEntity.successMessage(fileInfoTableVO);
    } 
    return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_NO_SEARCH_FILE_INFO.getCode()), StatusCodeEnum.DATA_RESOURCE_NO_SEARCH_FILE_INFO
        .getMessage());
  }
  
  public ResultEntity<FileInfoTableVO> getFileTableById(Long fileTableId) {
    FileInfoTablePO fileInfoTable = ((IFileInfoTableDao)ServiceUtil.getFileInfoTableDao(getDefaultCode(), IFileInfoTableDao.class)).getFileTableById(fileTableId);
    if (fileInfoTable != null) {
      FileInfoTableVO fileInfoTableVO = new FileInfoTableVO();
      BeanUtils.copyProperties(fileInfoTable, fileInfoTableVO);
      return ResultEntity.successMessage(fileInfoTableVO);
    } 
    return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_NO_SEARCH_FILE_INFO.getCode()), StatusCodeEnum.DATA_RESOURCE_NO_SEARCH_FILE_INFO
        .getMessage());
  }
  
  public ResultEntity<Boolean> saveFileTableId(Long directoryId, Long fileTableId, String tokenId) {
    IMetadataDao metadataDao = (IMetadataDao)ServiceUtil.getMetadataDao(getDefaultCode(), IMetadataDao.class);
    IFileInfoTableDao fileInfoTableDao = (IFileInfoTableDao)ServiceUtil.getFileInfoTableDao(getDefaultCode(), IFileInfoTableDao.class);
    List<MetadataEntityPO> metadataEntitys = metadataDao.selectMetadataEntityByDirectoryId(directoryId);
    if (metadataEntitys.size() > 0) {
      MetadataDirectoryPO metadataDirectoryPO = metadataDao.selectDirectoryByDirectoryId(directoryId);
      if (metadataDirectoryPO == null)
        return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_DATA_DIRECTORY_NOT_EXISTS.getCode()), StatusCodeEnum.DATA_RESOURCE_DATA_DIRECTORY_NOT_EXISTS
            .getMessage()); 
      Long oldFileId = metadataDirectoryPO.getFileTableId();
      ResultEntity<List<InterfaceEntityRelationVO>> resultEntity = this.dataInterfaceClient.getInterfaceEntityRelation(((MetadataEntityPO)metadataEntitys.get(0)).getEntityId(), 
          getDefaultCode(), tokenId);
      if (resultEntity.getCode().intValue() != 0)
        return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_GET_INTERFACE_REFERENCE_FAILED.getCode()), StatusCodeEnum.DATA_RESOURCE_GET_INTERFACE_REFERENCE_FAILED
            .getMessage()); 
      if (((List)resultEntity.getObj()).size() > 0) {
        List<String> relationNameList = (List<String>)((List)resultEntity.getObj()).stream().map(InterfaceEntityRelationVO::getInterfaceName).collect(Collectors.toList());
        String message = "此数据表应用于接口【" + Joiner.on("、").join((Iterable)relationNameList) + "】，请先删除数据表在接口中的应用";
        return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_DATA_TABLE_APPLY_INTERFACE_FIRST_DELETE.getCode()), message);
      } 
      if (fileTableId != null) {
        metadataDirectoryPO.setFileTableId(fileTableId);
        metadataDirectoryPO.setUpdateTime(new Date());
        metadataDao.updateMetadataDirectory(metadataDirectoryPO);
      } else {
        metadataDao.delFileTableId(directoryId);
      } 
      StringBuilder logInfo = new StringBuilder();
      if (null != fileTableId) {
        FileInfoTablePO fileTable = fileInfoTableDao.getFileTableById(fileTableId);
        if (fileTable != null) {
          String fileName = (fileTable.getFileTableCnName() != null) ? fileTable.getFileTableCnName() : fileTable.getFileTableName();
          if ("Manage".equals(getDefaultCode())) {
            logInfo.append("选择文件信息表 数据资源【");
          } else {
            logInfo.append("选择文件信息表 数据表【");
          } 
          logInfo.append(((MetadataEntityPO)metadataEntitys.get(0)).getEntityName()).append("】")
            .append("选择文件信息表【").append(fileName).append("】");
        } 
      } else {
        FileInfoTablePO fileTable = fileInfoTableDao.getFileTableById(oldFileId);
        if (fileTable != null) {
          String fileName = (fileTable.getFileTableCnName() != null) ? fileTable.getFileTableCnName() : fileTable.getFileTableName();
          if ("Manage".equals(getDefaultCode())) {
            logInfo.append("取消文件信息表 数据资源【");
          } else {
            logInfo.append("取消文件信息表 数据表【");
          } 
          logInfo.append(((MetadataEntityPO)metadataEntitys.get(0)).getEntityName()).append("】")
            .append("取消文件信息表【").append(fileName).append("】");
        } 
      } 
      if (logInfo.length() > 0)
        logSystemInfo(logInfo.toString(), getDefaultCode(), tokenId); 
      return ResultEntity.successMessage(Boolean.valueOf(true));
    } 
    return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_NO_FOUND_DATA_RESOURCE_ENTITY.getCode()), StatusCodeEnum.DATA_RESOURCE_NO_FOUND_DATA_RESOURCE_ENTITY
        .getMessage());
  }
  
  private boolean delFileInfoDbTable(DataStructProvider dataStructProvider, String fileTableName) {
    return dataStructProvider.dropTable(fileTableName);
  }
  
  public boolean renameFileInfoDbTable(DataStructProvider dataStructProvider, String oldFileTableName, String newFileTableName) {
    return dataStructProvider.renameTableName(oldFileTableName, newFileTableName);
  }
  
  public ResultEntity<Boolean> createFileInfoDbTable(DataStructProvider dataStructProvider, String fileTableName, String tokenId) {
    ResultEntity<List<MetadataTypeVO>> result = this.dataStandardClient.getMetadataTypeList(getDefaultCode(), tokenId);
    if (result.getCode().intValue() != 0 || CollectionUtils.isEmpty((Collection)result.getObj())) {
      logErrorInfo(null, "创建 数据源 物理表失败! 获取全部数据元列表失败! 返回信息: " + JSON.toJSONString(result), getDefaultCode(), tokenId);
      return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_CREATE_DATA_SOURCE_PHYSICAL_TABLE_FAILED.getCode()), StatusCodeEnum.DATA_RESOURCE_CREATE_DATA_SOURCE_PHYSICAL_TABLE_FAILED
          .getMessage());
    } 
    Map<String, MetadataTypeVO> metaTypeMap = new HashMap<>();
    ((List)result.getObj()).forEach(metadataTypeVO -> metaTypeMap.put(metadataTypeVO.getDataTypeName(), metadataTypeVO));
    Object object = new Object(this, metaTypeMap);
    boolean isGuid = DCConst.PrimaryKeyMode.GUID.equals(this.primaryKeyMode);
    if (isGuid) {
      object.add(new ColumnParamDTO(SysFieldHelper.getFileSysFieldName(FileSysFieldEnum.DBID), metaTypeMap.get("String"), COLUMN_LENGTH_36, null, 
            Integer.valueOf(1), Integer.valueOf(0)));
    } else {
      object.add(new ColumnParamDTO(SysFieldHelper.getFileSysFieldName(FileSysFieldEnum.DBID), metaTypeMap.get("Long"), 
            Integer.valueOf(0), null, Integer.valueOf(1), Integer.valueOf(0)));
    } 
    TableParamDTO table = new TableParamDTO();
    table.setTableName(fileTableName);
    table.setColumns((List)object);
    table.setSchemaName(dataStructProvider.currentDataSource.getDbSchema());
    return dataStructProvider.createTable(table, true);
  }
  
  public ResultEntity<Map<String, Integer>> handleOldDateForHistoryTable(String platCode, String tokenId) {
    Map<String, Integer> result = new HashMap<>();
    IFileInfoTableDao fileInfoTableDao = (IFileInfoTableDao)ServiceUtil.getFileInfoTableDao(getDefaultCode(), IFileInfoTableDao.class);
    Map<String, Object> param = new HashMap<>();
    List<FileInfoTablePO> fileInfoTableVOList = fileInfoTableDao.selectFileInfoTableList(param);
    Integer successCount = Integer.valueOf(0);
    Integer failCount = Integer.valueOf(0);
    if (fileInfoTableVOList != null && !fileInfoTableVOList.isEmpty())
      for (FileInfoTablePO fileInfoTablePO : fileInfoTableVOList) {
        try {
          if (fileInfoTablePO == null || DCConst.TRUE.equals(fileInfoTablePO.getIsDelete()))
            continue; 
          DataSourceVO dataSourceVO = null;
          if (fileInfoTablePO.getDataSourceId() != null)
            dataSourceVO = (DataSourceVO)this.dataStandardClient.getDataSourceInfoDoNotDecryptById(fileInfoTablePO.getDataSourceId(), platCode, tokenId).getObj(); 
          if (dataSourceVO == null || DCConst.TRUE.equals(dataSourceVO.getIsDelete()))
            continue; 
          DataStructProvider dataStructProvider = null;
          DataSourceDTO dataSourceDTO = new DataSourceDTO();
          BeanUtils.copyProperties(dataSourceVO, dataSourceDTO);
          ResultEntity<DataStructProvider> getDataBaseProviderRet = DataStructProvider.getDataBaseProvider(dataSourceDTO);
          if (!getDataBaseProviderRet.getCode().equals(Integer.valueOf(0)))
            continue; 
          dataStructProvider = (DataStructProvider)getDataBaseProviderRet.getObj();
          this.historyTableManager.saveHistoryTableForFileTable(dataStructProvider, fileInfoTablePO.getFileTableId(), fileInfoTablePO.getFileTableName(), getDefaultCode(), tokenId);
          Integer integer1 = successCount, integer2 = successCount = Integer.valueOf(successCount.intValue() + 1);
        } catch (Exception e) {
          logErrorInfo(ExceptionUtil.getStackTraceMsg(e), "同步文件信息表拉链表失败", getDefaultCode(), tokenId);
          Integer integer1 = failCount, integer2 = failCount = Integer.valueOf(failCount.intValue() + 1);
        } 
      }  
    result.put("successCount", successCount);
    result.put("failCount", failCount);
    return ResultEntity.successMessage(result);
  }
  
  public ResultEntity<Boolean> checkDataSourceIdApplyFileInfoTable(Long dataSourceId) {
    return ResultEntity.successMessage(Boolean.valueOf((((IFileInfoTableDao)ServiceUtil.getFileInfoTableDao(getDefaultCode(), IFileInfoTableDao.class)).selectFileInfoTableListCountByDataSourceId(dataSourceId) > 0)));
  }
  
  public ResultEntity<FileTableUsageVO> getFileTableUsedInfo(FileTableUsedInfoDTO usedInfoDTO, String platCode, String tokenId) {
    FileTableUsageVO result = new FileTableUsageVO();
    result.setDirectoryId(usedInfoDTO.getDirectoryId());
    result.setUsed(Boolean.valueOf(false));
    Long entityId = null;
    if ("Apply".equals(platCode)) {
      entityId = usedInfoDTO.getDirectoryId();
    } else {
      List<MetadataEntityPO> metadataEntityList = ((IMetadataDao)ServiceUtil.getMetadataDao(getDefaultCode(), IMetadataDao.class)).selectMetadataEntityByDirectoryId(usedInfoDTO.getDirectoryId());
      if (null != metadataEntityList && metadataEntityList.size() > 0)
        entityId = ((MetadataEntityPO)metadataEntityList.get(0)).getEntityId(); 
    } 
    if (null == entityId)
      return ResultEntity.successMessage(result); 
    List<FileTableUsedInterfaceVO> fileTableUsedInterfaces = (List<FileTableUsedInterfaceVO>)this.dataInterfaceClient.fileTableUsedInterface(entityId, usedInfoDTO.getFileTableId(), DCConst.FALSE, "Collection", tokenId).getObj();
    if (CollectionUtils.isEmpty(fileTableUsedInterfaces))
      return ResultEntity.successMessage(result); 
    result.setUsed(Boolean.valueOf(true));
    result.setCollectionInterface(fileTableUsedInterfaces);
    return ResultEntity.successMessage(result);
  }
  
  public ResultEntity<Boolean> deleteFileTableUsage(FileTableUsedInfoDTO usedInfoDTO, String platCode, String tokenId) {
    Long entityId = null;
    if ("Apply".equals(platCode)) {
      entityId = usedInfoDTO.getDirectoryId();
    } else {
      List<MetadataEntityPO> metadataEntityList = ((IMetadataDao)ServiceUtil.getMetadataDao(platCode, IMetadataDao.class)).selectMetadataEntityByDirectoryId(usedInfoDTO.getDirectoryId());
      if (null != metadataEntityList && metadataEntityList.size() > 0)
        entityId = ((MetadataEntityPO)metadataEntityList.get(0)).getEntityId(); 
    } 
    this.dataInterfaceClient.removeInterfaceConfigByFileTableId(entityId, usedInfoDTO.getFileTableId(), "Collection", tokenId);
    return ResultEntity.successMessage(Boolean.valueOf(true));
  }
  
  private List<MetadataDirectoryPO> getApplyEntityListOfFileTable(Long fileTableId) {
    return ((IMetadataDao)ServiceUtil.getMetadataDao(getDefaultCode(), IMetadataDao.class)).selectDirectoryListByFileTableId(fileTableId);
  }
  
  private void logErrorInfo(String stackInfo, String msg, String platCode, String tokenId) {
    CommonLogDTO logDTO = new CommonLogDTO();
    logDTO.setPlatCode(platCode);
    logDTO.setTokenId(tokenId);
    logDTO.setStackInformation(stackInfo);
    logDTO.setLoggerInformation(msg);
    logDTO.setLogLevel(FrameConst.Log.LOG_LEVEL_ERROR);
    logDTO.setLogType(0);
    logDTO.setModule_code(HeaderInterceptor.getModuleCode());
    RabbitMQUtil.publish("DC.Standard.log", logDTO);
  }
  
  private void logSystemInfo(String msg, String platCode, String tokenId) {
    CommonLogDTO logDTO = new CommonLogDTO();
    logDTO.setPlatCode(platCode);
    logDTO.setTokenId(tokenId);
    logDTO.setLoggerInformation(msg);
    logDTO.setLogLevel(FrameConst.Log.LOG_LEVEL_SYSTEM);
    logDTO.setLogType(0);
    logDTO.setModule_code(HeaderInterceptor.getModuleCode());
    RabbitMQUtil.publish("DC.Standard.log", logDTO);
  }
}
